<a name="unreleased"></a>
## [Unreleased]


<a name="v0.1.2"></a>
## [v0.1.2] - 2020-07-29
### Fix
- **performance:** do not format json output


<a name="v0.1.1"></a>
## [v0.1.1] - 2020-07-29
### Fix
- add option to suppress progress print on stdout
- pyproject classifier


<a name="v0.1.0"></a>
## v0.1.0 - 2020-07-29
### Build
- convert stuff for python
- add build support files

### Doc
- update readme

### Feat
- add docker support
- add commad to print app version
- add data processing and serving capabilities
- add python project skeleton


[Unreleased]: https://github.com/noandrea/plzpy/compare/v0.1.2...HEAD
[v0.1.2]: https://github.com/noandrea/plzpy/compare/v0.1.1...v0.1.2
[v0.1.1]: https://github.com/noandrea/plzpy/compare/v0.1.0...v0.1.1
